@@ -41,6 +41,8 @@
 
 #define PURPOSEWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(PURPOSEWIDGETS_NO_DEPRECATED) && !defined(PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define PURPOSEWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PURPOSEWIDGETS_NO_DEPRECATED
-#  define PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
+#  define PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56900
 #endif
 #ifdef PURPOSEWIDGETS_NO_DEPRECATED_WARNINGS
 #  define PURPOSEWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PURPOSEWIDGETS_DEPRECATED_WARNINGS_SINCE PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PURPOSEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x57400
+#    define PURPOSEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56900
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef PURPOSEWIDGETS_DEPRECATED
-#  define PURPOSEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define PURPOSEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define PURPOSEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
